==> dnet-openaire-datasource-manager-1.0.6-20190206.090643-5-sources.jar: eu/dnetlib/enabling/datasources/queries/searchApisUsingField.sql <==
SELECT * FROM (SELECT 
	a.id                                                                     AS "id",
	a.protocol                                                               AS "protocol",
	coalesce(a.compatibility_override, a.compatibility)                      AS "compliance",
	a.active                                                                 AS "active",
	a.baseurl                                                                AS "baseUrl",
	a.typology                                                               AS "type",
	coalesce(a.last_aggregation_date::text, a.last_download_date::text, '')  AS "aggrDate",
	coalesce(a.last_aggregation_total, a.last_download_total, 0)             AS "aggrTotal",
	ds.id                                                                    AS "dsId",
	ds.officialname                                                          AS "name",
	ds.englishname                                                           AS "alternativeName",
	ds.namespaceprefix                                                       AS "prefix",
	ds.websiteurl                                                            AS "websiteUrl",
	coalesce((array_agg(o.country))[1], '-')                                 AS "country",
    (array_agg(o.legalname))[1]                                              AS "organization"
FROM dsm_api a
	LEFT OUTER JOIN dsm_datasources ds ON (a.datasource = ds.id)
	LEFT OUTER JOIN dsm_datasource_organization dsorg ON (ds.id = dsorg.datasource)
	LEFT OUTER JOIN dsm_organizations o ON (dsorg.organization = o.id)
GROUP BY
	a.id,
	a.protocol,
	a.compatibility_override,
	a.compatibility,
	a.active,
	a.last_aggregation_date,
	a.last_download_date,
	a.last_aggregation_total,
	a.last_download_total,
	ds.id,
	ds.officialname,
	ds.englishname,
	ds.namespaceprefix,
	ds.websiteurl
) AS t WHERE

==> dnet-openaire-datasource-manager-2.0.1-20220421.073632-1-sources.jar: eu/dnetlib/enabling/datasources/queries/searchApisUsingField.sql <==
SELECT * FROM (SELECT 
	a.id                                                                     AS "id",
	a.protocol                                                               AS "protocol",
	coalesce(a.compatibility_override, a.compatibility)                      AS "compliance",
	a.active                                                                 AS "active",
	a.baseurl                                                                AS "baseUrl",
	ds.eosc_datasource_type                                                  AS "type",
	coalesce(a.last_aggregation_date::text, a.last_download_date::text, '')  AS "aggrDate",
	coalesce(a.last_aggregation_total, a.last_download_total, 0)             AS "aggrTotal",
	ds.id                                                                    AS "dsId",
	ds.officialname                                                          AS "name",
	ds.englishname                                                           AS "alternativeName",
	ds.namespaceprefix                                                       AS "prefix",
	ds.websiteurl                                                            AS "websiteUrl",
	coalesce((array_agg(o.country))[1], '-')                                 AS "country",
    (array_agg(o.legalname))[1]                                              AS "organization",
    ds.consenttermsofuse                                                     AS "consenttermsofuse",
    ds.fulltextdownload                                                      AS "fulltextdownload"
FROM dsm_api a
	LEFT OUTER JOIN dsm_services ds ON (a.service = ds.id)
	LEFT OUTER JOIN dsm_service_organization dsorg ON (ds.id = dsorg.service)
	LEFT OUTER JOIN dsm_organizations o ON (dsorg.organization = o.id)
WHERE ds.dedup_main_service = true
GROUP BY
	a.id,
	a.protocol,
	a.compatibility_override,
	a.compatibility,
	a.active,
	a.last_aggregation_date,
	a.last_download_date,
	a.last_aggregation_total,
	a.last_download_total,
	ds.id,
	ds.officialname,
	ds.englishname,
	ds.namespaceprefix,
	ds.websiteurl,
	ds.consenttermsofuse,
    ds.fulltextdownload,
    eosc_datasource_type
) AS t WHERE
